package mi.hdm.controllers;

import javafx.fxml.FXML;
import javafx.scene.control.Label;
import javafx.scene.layout.AnchorPane;
import javafx.scene.layout.TilePane;
import javafx.scene.layout.VBox;
import mi.hdm.recipes.Recipe;
import mi.hdm.recipes.RecipeManager;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class MainPageController extends BaseController {
    private final static Logger log = LogManager.getLogger(MainPageController.class);

    private final RecipeManager recipeManager;

    @FXML
    private AnchorPane parent;
    @FXML
    private TilePane recipeTilePane;

    public MainPageController(RecipeManager recipeManager) {
        this.recipeManager = recipeManager;
    }

    @FXML
    public void initialize() {
        loadHeader(parent);
        mapRecipes();
        log.debug("Added {} recipes to GUI", recipeManager.getRecipes().size());
    }

    @FXML
    public void addRecipe() {
        log.info("User is trying to add recipe!");
    }

    private void mapRecipes() {
        for (Recipe recipe : recipeManager.getRecipes()) {
            Label recipeName = new Label(recipe.getName());
            Label recipeDescription = new Label(recipe.getDescription());
            VBox currentRecipeBox = new VBox(recipeName, recipeDescription);

            //TODO: make this recipe box a component class
            recipeName.setStyle(
                    "-fx-font-weight: 800;" +
                            "-fx-font-scale: 16"
            );

            currentRecipeBox.setPrefWidth(180);
            currentRecipeBox.setPrefHeight(250);
            currentRecipeBox.setStyle(
                    "-fx-background-color: #DEDEDE;" +
                            "-fx-border-color: #D91C1C;" +
                            "-fx-border-radius: 8;" +
                            "-fx-border-width: 2;" +
                            "-fx-padding: 8"
            );

            recipeTilePane.getChildren().add(currentRecipeBox);
        }
    }
}
